@@ -36,25 +36,11 @@
 
 #include <utils/gnupg-helper.h>
 
-#include <QGpgME/Protocol>
-#include <QGpgME/CryptoConfig>
-
 #include <KLocalizedString>
 #include <KMessageBox>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
-using namespace QGpgME;
-
-static bool haveKeyserverConfigured()
-{
-    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
-    if (!config) {
-        return false;
-    }
-    const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Keyserver"), QStringLiteral("keyserver"));
-    return entry && !entry->stringValue().isEmpty();
-}
 
 RefreshOpenPGPCertsCommand::RefreshOpenPGPCertsCommand(KeyListController *c)
     : GnuPGProcessCommand(c)
@@ -130,7 +116,7 @@ QString RefreshOpenPGPCertsCommand::crashExitMessage(const QStringList &args) co
     return xi18nc("@info",
                   "<para>The GPG process that tried to refresh OpenPGP certificates "
                   "ended prematurely because of an unexpected error.</para>"
-                  "<para>Please check the output of <icode>%1</icode> for details.</para>", args.join(QStringLiteral(" ")));
+                  "<para>Please check the output of <icode>%1</icode> for details.</para>", args.join(QLatin1Char(' ')));
 }
 
 QString RefreshOpenPGPCertsCommand::errorExitMessage(const QStringList &args) const
@@ -138,7 +124,7 @@ QString RefreshOpenPGPCertsCommand::errorExitMessage(const QStringList &args) co
     return i18nc("@info",
                  "<para>An error occurred while trying to refresh OpenPGP certificates.</para> "
                  "<para>The output from <command>%1</command> was: <message>%2</message></para>",
-                 args[0], errorString().replace(QStringLiteral("\n"), QStringLiteral("<br>")));
+                 args[0], errorString().replace(QLatin1Char('\n'), QStringLiteral("<br>")));
 }
 
 QString RefreshOpenPGPCertsCommand::successMessage(const QStringList &) const
